Welcome to Orange3 Single Cell Documentation
============================================

Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/load_data
   widgets/single_cell_datasets
   widgets/filter
   widgets/single_cell_preprocess
   widgets/batch_effect_removal
   widgets/align_datasets
   widgets/score_genes
   widgets/score_cells
   widgets/dot_matrix
